==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebDockManagerPointDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescription } from "./WebDockManagerPointDescription";
/**
 * @hidden
 */
var WebDockManagerPointDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDockManagerPointDescriptionMetadata, _super);
    function WebDockManagerPointDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerPointDescriptionMetadata.b = function (a) {
        if (WebDockManagerPointDescriptionMetadata.a == null) {
            WebDockManagerPointDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockManagerPointDescriptionMetadata.c(WebDockManagerPointDescriptionMetadata.a);
        }
        if (a.g(WebDockManagerPointDescriptionMetadata.a)) {
            return;
        }
        a.s(WebDockManagerPointDescriptionMetadata.a);
    };
    WebDockManagerPointDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockManagerPoint");
        a.item("X", "Number:double");
        a.item("Y", "Number:double");
    };
    WebDockManagerPointDescriptionMetadata.d = function (a) {
        WebDockManagerPointDescriptionMetadata.b(a);
        a.u("WebDockManagerPoint", function () { return new WebDockManagerPointDescription(); });
        a.t("WebDockManagerPoint", WebDockManagerPointDescriptionMetadata.a);
    };
    WebDockManagerPointDescriptionMetadata.$t = markType(WebDockManagerPointDescriptionMetadata, 'WebDockManagerPointDescriptionMetadata');
    WebDockManagerPointDescriptionMetadata.a = null;
    return WebDockManagerPointDescriptionMetadata;
}(Base));
export { WebDockManagerPointDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebDockManagerPointDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescription } from "./WebDockManagerPointDescription";
/**
 * @hidden
 */
var WebDockManagerPointDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDockManagerPointDescriptionMetadata, _super);
    function WebDockManagerPointDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDockManagerPointDescriptionMetadata.b = function (a) {
        if (WebDockManagerPointDescriptionMetadata.a == null) {
            WebDockManagerPointDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDockManagerPointDescriptionMetadata.c(WebDockManagerPointDescriptionMetadata.a);
        }
        if (a.j(WebDockManagerPointDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDockManagerPointDescriptionMetadata.a);
    };
    WebDockManagerPointDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DockManagerPoint");
        a.item("X", "Number:double");
        a.item("Y", "Number:double");
    };
    WebDockManagerPointDescriptionMetadata.d = function (a) {
        WebDockManagerPointDescriptionMetadata.b(a);
        a.aa("WebDockManagerPoint", function () { return new WebDockManagerPointDescription(); });
        a.z("WebDockManagerPoint", WebDockManagerPointDescriptionMetadata.a);
    };
    WebDockManagerPointDescriptionMetadata.$t = markType(WebDockManagerPointDescriptionMetadata, 'WebDockManagerPointDescriptionMetadata');
    WebDockManagerPointDescriptionMetadata.a = null;
    return WebDockManagerPointDescriptionMetadata;
}(Base));
export { WebDockManagerPointDescriptionMetadata };
